@@ -328,7 +328,7 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         self.assertEqual(prop_info['instrument_identifier'], 'SPB')
 
     def test_get_proposal_details_error_sample(self):
-        resp = self.mdc_client.get_proposal_info(2194, ['SA1', 'SA2', 'SA3'])
+        resp = self.mdc_client.get_proposal_info(900966, ['SA1', 'SA2', 'SA3'])
 
         # Logging information
         logging.error('resp: {0}'.format(resp))
@@ -336,7 +336,7 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         # Expected return:
         #
         self.assert_eq_val(resp['info'], 'Error getting proposal')
-        self.assert_eq_val(resp['app_info'], 'The proposal beamline status is in a finished status in myMdC!')  # noqa
+        self.assert_eq_val(resp['app_info'], 'The proposal has no Samples defined yet in myMdC!')  # noqa
         self.assert_eq_val(resp['success'], False)
         self.assert_eq_val(resp['data'], {})
 
